/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.Optional;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.datastructure.ConcretePolygon;
import de.hft.stuttgart.citydoctor2.datastructure.GmlId;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;
import de.hft.stuttgart.quality.model.NonPlanarDistancePlane;
import de.hft.stuttgart.quality.model.ValidationError;

public class NonPlanarPolygonDistancePlaneErrorTest {

	@Test
	public void testConvertToQualityAdeDatastructure() {
		Polygon p1 = new ConcretePolygon();
		GmlId p1Id = new GmlId("p1Id");
		p1.setGmlId(p1Id);
		
		Vertex v = new Vertex(1, 2, 3);

		NonPlanarPolygonDistancePlaneError err = new NonPlanarPolygonDistancePlaneError(p1, 5, v, null);
		Optional<ValidationError> optional = err.convertToQualityAdeDatastructure();
		assertTrue(optional.isPresent());
		
		NonPlanarDistancePlane error = (NonPlanarDistancePlane) optional.get();
		assertEquals(p1Id.getGmlString(), error.getPolygonId());
		assertEquals(1, error.getVertex().getValue().get(0), 0.00001);
		assertEquals(5, error.getDistance().getValue(), 0.000001);
	}

}
	